@@ -12,7 +12,7 @@ def main(config_fname=None):
     from pysyncobj import SyncObjConf
 
     from pushpy.batteries import ReplLockDataManager
-    from pushpy.code_utils import load_in_memory_module, create_in_memory_module
+    from pushpy.code_store import load_in_memory_module, create_in_memory_module
     from pushpy.host_resources import HostResources, GPUResources, get_cluster_info, get_partition_info
     from pushpy.push_manager import PushManager
     from pushpy.push_server_utils import load_config, serve_forever, host_to_address
@@ -61,7 +61,6 @@ def main(config_fname=None):
 
     repl_hosts = ReplLockDataManager(autoUnlockTime=5)
     boot_globals, web_router = boot_mod.main()
-    print(boot_globals)
     boot_consumers = [x for x in boot_globals.values() if isinstance(x, SyncObjConsumer) or hasattr(x, '_consumer')]
     sync_obj = SyncObj(sync_obj_host, sync_obj_peers, consumers=[repl_hosts, *boot_consumers], conf=SyncObjConf(dynamicMembershipChange=True))
 
@@ -125,11 +124,10 @@ def main(config_fname=None):
     boot_common = create_in_memory_module(name="boot_common")
 
     for k, v in boot_globals.items():
-        globals()[k] = v
         boot_common.__dict__[k] = v
         if k.startswith("repl_") or k.startswith("local_"):
             # https://stackoverflow.com/questions/2295290/what-do-lambda-function-closures-capture
-            PushManager.register(k, callable=lambda q=k: globals()[q])
+            PushManager.register(k, callable=lambda vv=v: vv)
 
     print(f"registering host: {sync_obj.selfNode.id}")
     sync_obj.waitReady()
